From: Stephen Rothwell <sfr@canb•auug.org.au>
To: Andrew Morton <akpm@linux-foundation•org>,
Jonathan Corbet <corbet@lwn•net>
Cc: linux-next@vger•kernel.org, linux-kernel@vger•kernel.org,
Robert Elliott <elliott@hpe•com>,
Taku Izumi <izumi.taku@jp•fujitsu.com>
Subject: linux-next: manual merge of the akpm-current tree with the jc_docs tree
Date: Thu, 31 Dec 2015 21:58:49 +1100 [thread overview]
Message-ID: <20151231215849.01be6998@canb.auug.org.au> (raw)
Hi Andrew,
Today's linux-next merge of the akpm-current tree got a conflict in:
mm/page_alloc.c
between commit:
9daacf51b428 ("Documentation/kernel-parameters: update KMG units")
from the jc_docs tree and commit:
f0a906868be1 ("mm/page_alloc.c: introduce kernelcore=mirror option")
from the akpm-current tree.
I fixed it up (see below) and can carry the fix as necessary (no action
is required).
--
Cheers,
Stephen Rothwell sfr@canb•auug.org.au
diff --cc mm/page_alloc.c
index 13cf824f6d23,72218a4adab9..000000000000
--- a/mm/page_alloc.c
+++ b/mm/page_alloc.c
@@@ -5500,7 -5718,37 +5718,37 @@@ static void __init find_zone_movable_pf
}
/*
+ * If kernelcore=mirror is specified, ignore movablecore option
+ */
+ if (mirrored_kernelcore) {
+ bool mem_below_4gb_not_mirrored = false;
+
+ for_each_memblock(memory, r) {
+ if (memblock_is_mirror(r))
+ continue;
+
+ nid = r->nid;
+
+ usable_startpfn = memblock_region_memory_base_pfn(r);
+
+ if (usable_startpfn < 0x100000) {
+ mem_below_4gb_not_mirrored = true;
+ continue;
+ }
+
+ zone_movable_pfn[nid] = zone_movable_pfn[nid] ?
+ min(usable_startpfn, zone_movable_pfn[nid]) :
+ usable_startpfn;
+ }
+
+ if (mem_below_4gb_not_mirrored)
+ pr_warn("This configuration results in unmirrored kernel memory.");
+
+ goto out2;
+ }
+
+ /*
- * If movablecore=nn[KMG] was specified, calculate what size of
+ * If movablecore=nn[KMGTPE] was specified, calculate what size of
* kernelcore that corresponds so that memory usable for
* any allocation type is evenly spread. If both kernelcore
* and movablecore are specified, then the value of kernelcore
next reply other threads:[~2015-12-31 10:58 UTC|newest]
Thread overview: 15+ messages / expand[flat|nested] mbox.gz Atom feed top
2015-12-31 10:58 Stephen Rothwell [this message]
-- strict thread matches above, loose matches on Subject: below --
2020-07-14 8:19 linux-next: manual merge of the akpm-current tree with the jc_docs tree Stephen Rothwell
2020-04-22 6:01 Stephen Rothwell
2020-03-11 7:11 Stephen Rothwell
2019-10-02 3:18 Stephen Rothwell
2018-05-09 10:25 Stephen Rothwell
2018-05-09 13:28 ` Andrea Parri
2018-05-09 13:30 ` Andrea Parri
2018-05-09 14:59 ` Jonathan Corbet
2018-05-09 16:53 ` Andrea Parri
2018-05-09 17:11 ` Jonathan Corbet
2018-05-09 17:35 ` Andrea Parri
2016-12-14 3:42 Stephen Rothwell
2015-12-31 10:43 Stephen Rothwell
2015-12-31 17:47 ` Elliott, Robert (Persistent Memory)
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20151231215849.01be6998@canb.auug.org.au \
--to=sfr@canb$(echo .)auug.org.au \
--cc=akpm@linux-foundation$(echo .)org \
--cc=corbet@lwn$(echo .)net \
--cc=elliott@hpe$(echo .)com \
--cc=izumi.taku@jp$(echo .)fujitsu.com \
--cc=linux-kernel@vger$(echo .)kernel.org \
--cc=linux-next@vger$(echo .)kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox